/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StorageEvent.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomDOMWindow.h"
#include "gdom/GdomEvent.h"
#include "gdom/GdomStorageEvent.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomDOMWindow.h"
#include "gdom/PrivateGdomEvent.h"
#include "gdom/PrivateGdomStorageEvent.h"
#include "gdom/PrivateIntGdomDOMWindow.h"
#include "gdom/PrivateIntGdomStorageEvent.h"
#include "glib-object.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMStorageEvent::GDOMStorageEvent(PassRefPtr<WebCore::StorageEvent> impl)
    : GDOMEvent(impl)
{
}

void
gdom_storage_event_init_storage_event (GdomStorageEvent *thiz, gchar * type_arg, gboolean can_bubble_arg, gboolean cancelable_arg, gchar * key_arg, gchar * old_value_arg, gchar * new_value_arg, gchar * uri_arg, GdomDOMWindow * source_arg)
{
    g_return_if_fail (thiz);
    WebCore::StorageEvent * item = (gdom_storage_event_get_private(thiz));
    g_return_if_fail (item);
    g_return_if_fail (type_arg);
    g_return_if_fail (key_arg);
    g_return_if_fail (old_value_arg);
    g_return_if_fail (new_value_arg);
    g_return_if_fail (uri_arg);
    g_return_if_fail (source_arg);
    WebCore::String _g_type_arg = WebCore::String::fromUTF8(type_arg);
    WebCore::String _g_key_arg = WebCore::String::fromUTF8(key_arg);
    WebCore::String _g_old_value_arg = WebCore::String::fromUTF8(old_value_arg);
    WebCore::String _g_new_value_arg = WebCore::String::fromUTF8(new_value_arg);
    WebCore::String _g_uri_arg = WebCore::String::fromUTF8(uri_arg);
    WebCore::DOMWindow * _g_source_arg = (gdom_dom_window_get_private(source_arg));
    g_return_if_fail (_g_source_arg);
    item->initStorageEvent(_g_type_arg, can_bubble_arg, cancelable_arg, _g_key_arg, _g_old_value_arg, _g_new_value_arg, _g_uri_arg, _g_source_arg);

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "StorageEvent.h"
#include <gdom/GdomStorageEvent.h>
#include <gdom/PrivateGdomStorageEvent.h>
#include <gdom/PrivateIntGdomStorageEvent.h>
#include <gdom/GdomStorageEventprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomStorageEvent, gdom_storage_event, GDOM_TYPE_EVENT);

/*
struct _GdomStorageEventPrivate {
    class WebCore::StorageEvent *item;
};

#define GDOM_STORAGE_EVENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_STORAGE_EVENT, GdomStorageEventPrivate))
*/
G_END_DECLS
WebCore::StorageEvent *
gdom_storage_event_get_private(GdomStorageEvent *request)
{
    GDOMStorageEvent *res;
    res = static_cast<GDOMStorageEvent*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::StorageEvent*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_KEY,
    PROP_OLD_VALUE,
    PROP_NEW_VALUE,
    PROP_URI,
    PROP_SOURCE,
};


static void gdom_storage_event_finalize(GObject* object)
{
    /*GdomStorageEvent* request = GDOM_STORAGE_EVENT(object);*/
    /*GdomStorageEventPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_EVENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_storage_event_parent_class)->finalize(object);
}

static void gdom_storage_event__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomStorageEvent *self = GDOM_STORAGE_EVENT(object);
    WebCore::StorageEvent * gself = (gdom_storage_event_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_storage_event__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomStorageEvent *self = GDOM_STORAGE_EVENT(object);
    WebCore::StorageEvent * gself = (gdom_storage_event_get_private(self));
    switch (prop_id) {
    case PROP_KEY:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->key()));
         break;
    }
    case PROP_OLD_VALUE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->oldValue()));
         break;
    }
    case PROP_NEW_VALUE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->newValue()));
         break;
    }
    case PROP_URI:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->uri()));
         break;
    }
    case PROP_SOURCE:
    {
         PassRefPtr<WebCore::DOMWindow> ptr = gself->source();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_storage_event_class_init(GdomStorageEventClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_storage_event_finalize;
    g_klass->set_property = gdom_storage_event__set_property_fn;
    g_klass->get_property = gdom_storage_event__get_property_fn;

    g_object_class_install_property (g_klass, PROP_KEY,
            g_param_spec_string ("key", /* name */
                "storage_event_key", /* short description */
                "read-only  gchar * StorageEvent.key", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_OLD_VALUE,
            g_param_spec_string ("old_value", /* name */
                "storage_event_old_value", /* short description */
                "read-only  gchar * StorageEvent.old_value", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_NEW_VALUE,
            g_param_spec_string ("new_value", /* name */
                "storage_event_new_value", /* short description */
                "read-only  gchar * StorageEvent.new_value", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_URI,
            g_param_spec_string ("uri", /* name */
                "storage_event_uri", /* short description */
                "read-only  gchar * StorageEvent.uri", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_SOURCE,
            g_param_spec_object ("source", /* name */
                "storage_event_source", /* short description */
                "read-only  GdomDOMWindow * StorageEvent.source", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_DOM_WINDOW, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomStorageEventPrivate));*/
}

static void gdom_storage_event_init(GdomStorageEvent* request)
{
    /*GdomStorageEventPrivate* priv = GDOM_STORAGE_EVENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

